pub enum AggregateModifier {
None,
By(Vec<String>),
Without(Vec<String>),
}Expand description
The aggregation modifier can be used to indicate the aggregation operators to use or exclude certain dimensions.
Variants
None
By(Vec<String>)
The by modifier drops labels that are not listed.
Without(Vec<String>)
The without modifier removes the listed labels from the result vector.
All other labels are preserved.
Implementations